/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

import nl.cloudfarming.client.isobus.model.BinaryDataType;
import nl.cloudfarming.client.isobus.model.XmlField;

/**
 * Describes fields of ISO 17783-10 DLV(DatatLogValue) element and it's dataType in the binary file
 * @author Gerben Feenstra
 */
public enum DatalogValueFieldEnum implements XmlField {

    PROCESS_DATA_DDI("A",BinaryDataType.BIT32_SIGNED),
    
    DATALOGVALUE_NR("unknown", BinaryDataType.BIT8_SIGNED),
    
    DATALOGVALUE_COUNT("unknown", BinaryDataType.BIT8_SIGNED),
    
    /** DLV B **/
    DATALOGVALUE_PROCESSDATA_VALUE("B", BinaryDataType.BIT32_SIGNED),
    
    DEVICE_ELEMENT_ID_REF("C", BinaryDataType.BIT32_SIGNED);
    
    String xmlField = "";
    BinaryDataType dataType;
    
    DatalogValueFieldEnum(String xmlField, BinaryDataType dataType) {
        this.xmlField = xmlField;
        this.dataType = dataType;
    }

    @Override
    public String getAttributeName() {
        return xmlField;

    }

    @Override
    public BinaryDataType getDataType() {
        return dataType;
    }
}
