/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

import java.util.concurrent.Callable;
import nl.cloudfarming.client.isobus.model.IsobusGrid;
import nl.cloudfarming.client.util.Callback;
import org.geotools.coverage.grid.GridCoverage2D;

/**
 * A grid for isobus GRD[0-9][0-9[0-9[0-9[0-9].bin files
 * @author Merijn Zengers
 */
public class IsobusRaster extends nl.cloudfarming.client.geoviewer.Grid {

    private IsobusGrid grid;
    private IsobusValueGrid valueGrid;
    
    /**
     * Constructs a IsobusRaster object
     * Needs a grid object to get the grid properties from
     * Needs a list of treatment zones to fill the grid with 
     * Take note:! the order of the list of treatMentzones is important
     * assumes the order is the same as in which it is read from the GRD[0-9][0-9[0-9[0-9[0-9.bin file
     * starting at the left bottom of the grid and ending at the right top
     * @param grid the grid to Create a raster for
     * @param valueGrid the values to fill the raster with
     */
    public IsobusRaster(final IsobusGrid grid, final IsobusValueGrid valueGrid, final Callback<double[]> rangeCallback){
        super(new Callable<GridCoverage2D>() {

            @Override
            public GridCoverage2D call() throws Exception {
                return RasterFactory.createRaster(grid, valueGrid, rangeCallback);
            }
        });
        this.grid = grid;
        this.valueGrid = valueGrid;
    }

    @Override
    public String getTooltipText() {
        return "";
    }
   
}
