/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.isobus.type;

import java.awt.Image;
import java.util.concurrent.Callable;
import nl.cloudfarming.client.geoviewer.Grid;
import nl.cloudfarming.client.isobus.model.DDI;
import nl.cloudfarming.client.util.Callback;
import org.geotools.coverage.grid.GridCoverage2D;
import org.openide.util.ImageUtilities;

/**
 * Geographical to show logged process data values.
 * E.g. applied rate and yield maps.
 * 
 * @author johan
 */
public class TimeLogGrid extends Grid {
    public static final String GRID_ICON_BASE = "nl/cloudfarming/client/isobus/type/action_log.png";

    private final DDI ddi;
    private final String iconBase;

    public TimeLogGrid(final TimeLogBinaryDataObject binary, final DDI ddi, final Callback<double[]> rangeCallback, String iconBase) {
        super(new Callable<GridCoverage2D>() {

            @Override
            public GridCoverage2D call() throws Exception {
                return RasterFactory.createRaster(binary, ddi, rangeCallback);
            }
        });
        this.ddi = ddi;
        this.iconBase = iconBase;
    }
    
    public TimeLogGrid(final TimeLogBinaryDataObject binary, final DDI ddi, final Callback<double[]> rangeCallback) {
        this(binary, ddi, rangeCallback, GRID_ICON_BASE);
    }

    public DDI getDDI() {
        return ddi;
    }

    @Override
    public String getTooltipText() {
        return ddi == null ? "" : ddi.getDescription();
    }

    @Override
    public Image getIcon() {
        return ImageUtilities.loadImage(iconBase);
    }
}
