/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.isobus.type;

import com.vividsolutions.jts.geom.Coordinate;
import eu.agrosense.client.grid.util.AggregationGrid;
import eu.agrosense.client.grid.util.RasterHelper;
import nl.cloudfarming.client.isobus.model.DDI;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import nl.cloudfarming.client.isobus.model.IsobusTime;
import nl.cloudfarming.client.isobus.type.TimeLogGridTransformationStrategies.TimeLogTransformationContext;

/**
 * Strategy to extract values to be plotted from a timelog record for a specific DDI.
 * 
 * A single record/ddi combination can produce multiple values when sections are used.
 * 
 * @author johan
 */
public abstract class TimeLogGridCalculationStrategy {
    protected final TimeLogBinaryDataObject binary;
    protected final AggregationGrid<TimeLogTransformationContext> aggregationGrid;
    protected final TimeLogTransformationContext context = new TimeLogTransformationContext();
    protected final DDI ddiToPlot;
    protected final RasterHelper rasterHelper;
    // vehicle origin:
    protected final Coordinate origin = new Coordinate();

    /**
     * 
     * @param binary
     * @param aggregationGrid
     * @param ddi
     * @param rasterHelper 
     */
    public TimeLogGridCalculationStrategy(TimeLogBinaryDataObject binary, AggregationGrid<TimeLogTransformationContext> aggregationGrid, DDI ddi, RasterHelper rasterHelper) {
        this.binary = binary;
        this.aggregationGrid = aggregationGrid;
        this.ddiToPlot = ddi;
        this.rasterHelper = rasterHelper;
    }

    /**
     * Handle a single timelog record.
     * Calculated values (if any) will be forwarded to the aggregation strategy.
     * 
     * @param isobusTime
     * @param gpsDerivedValue 
     */
    public void handle(IsobusTime isobusTime, GpsDerivedValue gpsDerivedValue) {
        context.setIsobusTime(isobusTime);
        context.setGpsDerivedValue(gpsDerivedValue);
        
        // handle common actions like maintaining vehicle or main device position:
        origin.x = isobusTime.getPTN().getPositionEast().doubleValue();
        origin.y = isobusTime.getPTN().getPositionNorth().doubleValue();
        
        handleInternal(isobusTime, gpsDerivedValue);
    }
    
    protected abstract void handleInternal(IsobusTime isobusTime, GpsDerivedValue gpsDerivedValue);
    
    protected final void add(Coordinate coordinate, double value, DeviceElement deviceElement) {
        Integer x = rasterHelper.getX(coordinate.x);
        Integer y = rasterHelper.getY(coordinate.y);
        if (x != null && y != null) {
            context.setDeviceElement(deviceElement);
            aggregationGrid.add(x, y, value, context);
        }       
    }
    
}
